@@ -23,7 +23,7 @@ instruction:
 """
 import re
 from collections import ChainMap
-from typing import Mapping, MutableSequence, Sequence, Tuple
+from typing import Mapping, MutableSequence, Tuple
 from xml.etree.ElementTree import Element
 
 import yaml
@@ -35,13 +35,13 @@ from markdown.extensions import Extension
 from markdown.treeprocessors import Treeprocessor
 from mkdocs_autorefs.plugin import AutorefsPlugin
 
-from mkdocstrings.handlers.base import CollectionError, CollectorItem, Handlers
+from mkdocstrings.handlers.base import BaseHandler, CollectionError, CollectorItem, Handlers
 from mkdocstrings.loggers import get_logger
 
 try:
     from mkdocs.exceptions import PluginError  # New in MkDocs 1.2
 except ImportError:
-    PluginError = SystemExit
+    PluginError = SystemExit  # noqa: WPS440
 
 
 log = get_logger(__name__)
@@ -79,7 +79,7 @@ class AutoDocProcessor(BlockProcessor):
         self._autorefs = autorefs
         self._updated_env = False
 
-    def test(self, parent: Element, block: str) -> bool:
+    def test(self, parent: Element, block: str) -> bool:  # type: ignore
         """Match our autodoc instructions.
 
         Arguments:
@@ -117,15 +117,26 @@ class AutoDocProcessor(BlockProcessor):
             heading_level = match["heading"].count("#")
             log.debug(f"Matched '::: {identifier}'")
 
-            html, headings = self._process_block(identifier, block, heading_level)
+            html, handler = self._process_block(identifier, block, heading_level)
             el = Element("div", {"class": "mkdocstrings"})
             # The final HTML is inserted as opaque to subsequent processing, and only revealed at the end.
             el.text = self.md.htmlStash.store(html)
             # So we need to duplicate the headings directly (and delete later), just so 'toc' can pick them up.
+            headings = handler.renderer.get_headings()
             el.extend(headings)
 
             for heading in headings:
-                self._autorefs.register_anchor(self._autorefs.current_page, heading.attrib["id"])
+                page = self._autorefs.current_page
+                anchor = heading.attrib["id"]
+                self._autorefs.register_anchor(page, anchor)
+
+                if "data-role" in heading.attrib:
+                    self._handlers.inventory.register(
+                        name=anchor,
+                        domain=handler.domain,
+                        role=heading.attrib["data-role"],
+                        uri=f"{page}#{anchor}",
+                    )
 
             parent.append(el)
 
@@ -135,7 +146,7 @@ class AutoDocProcessor(BlockProcessor):
             # list for future processing.
             blocks.insert(0, the_rest)
 
-    def _process_block(self, identifier: str, yaml_block: str, heading_level: int = 0) -> Tuple[str, Sequence[Element]]:
+    def _process_block(self, identifier: str, yaml_block: str, heading_level: int = 0) -> Tuple[str, BaseHandler]:
         """Process an autodoc block.
 
         Arguments:
@@ -148,7 +159,7 @@ class AutoDocProcessor(BlockProcessor):
             TemplateNotFound: When a template used for rendering could not be found.
 
         Returns:
-            Rendered HTML and the list of heading elements encoutered.
+            Rendered HTML and the handler that was used.
         """
         config = yaml.safe_load(yaml_block) or {}
         handler_name = self._handlers.get_handler_name(config)
@@ -172,7 +183,7 @@ class AutoDocProcessor(BlockProcessor):
 
         if not self._updated_env:
             log.debug("Updating renderer's env")
-            handler.renderer._update_env(self.md, self._config)  # noqa: W0212 (protected member OK)
+            handler.renderer._update_env(self.md, self._config)  # noqa: WPS437 (protected member OK)
             self._updated_env = True
 
         log.debug("Rendering templates")
@@ -185,7 +196,7 @@ class AutoDocProcessor(BlockProcessor):
             )
             raise
 
-        return (rendered, handler.renderer.get_headings())
+        return (rendered, handler)
 
 
 def get_item_configs(handler_config: dict, config: dict) -> Tuple[Mapping, Mapping]:
