@@ -11,7 +11,7 @@ It also provides two methods:
 import importlib
 from abc import ABC, abstractmethod
 from pathlib import Path
-from typing import Any, Dict, Iterable, Optional, Sequence
+from typing import Any, Dict, Iterable, List, Optional, Sequence
 from xml.etree.ElementTree import Element, tostring
 
 from jinja2 import Environment, FileSystemLoader
@@ -24,6 +24,7 @@ from mkdocstrings.handlers.rendering import (
     IdPrependingTreeprocessor,
     MkdocstringsInnerExtension,
 )
+from mkdocstrings.inventory import Inventory
 from mkdocstrings.loggers import get_template_logger
 
 CollectorItem = Any
@@ -95,7 +96,7 @@ class BaseRenderer(ABC):
         for path in paths:
             css_path = path / "style.css"
             if css_path.is_file():
-                self.extra_css += "\n" + css_path.read_text(encoding="utf-8")
+                self.extra_css += "\n" + css_path.read_text(encoding="utf-8")  # noqa: WPS601
                 break
 
         if custom_templates is not None:
@@ -103,14 +104,14 @@ class BaseRenderer(ABC):
 
         self.env = Environment(
             autoescape=True,
-            loader=FileSystemLoader(paths),
+            loader=FileSystemLoader(paths),  # type: ignore
             auto_reload=False,  # Editing a template in the middle of a build is not useful.
         )  # type: ignore
         self.env.filters["any"] = do_any
         self.env.globals["log"] = get_template_logger()
 
-        self._headings = []
-        self._md = None  # To be populated in `update_env`.
+        self._headings: List[Element] = []
+        self._md: Markdown = None  # type: ignore  # To be populated in `update_env`.
 
     @abstractmethod
     def render(self, data: CollectorItem, config: dict) -> str:
@@ -163,6 +164,7 @@ class BaseRenderer(ABC):
         content: str,
         heading_level: int,
         *,
+        role: Optional[str] = None,
         hidden: bool = False,
         toc_label: Optional[str] = None,
         **attributes: str,
@@ -172,6 +174,7 @@ class BaseRenderer(ABC):
         Arguments:
             content: The HTML within the heading.
             heading_level: The level of heading (e.g. 3 -> `h3`).
+            role: An optional role for the object bound to this heading.
             hidden: If True, only register it for the table of contents, don't render anything.
             toc_label: The title to use in the table of contents ('data-toc-label' attribute).
             attributes: Any extra HTML attributes of the heading.
@@ -182,8 +185,10 @@ class BaseRenderer(ABC):
         # First, produce the "fake" heading, for ToC only.
         el = Element(f"h{heading_level}", attributes)
         if toc_label is None:
-            toc_label = content.unescape() if isinstance(el, Markup) else content
+            toc_label = content.unescape() if isinstance(el, Markup) else content  # type: ignore
         el.set("data-toc-label", toc_label)
+        if role:
+            el.set("data-role", role)
         self._headings.append(el)
 
         if hidden:
@@ -285,8 +290,16 @@ class BaseHandler:
     Inherit from this class to implement a handler.
 
     It's usually just a combination of a collector and a renderer, but you can make it as complex as you need.
+
+    Attributes:
+        domain: The cross-documentation domain/language for this handler.
+        enable_inventory: Whether this handler is interested in enabling the creation
+            of the `objects.inv` Sphinx inventory file.
     """
 
+    domain: str = "default"
+    enable_inventory: bool = False
+
     def __init__(self, collector: BaseCollector, renderer: BaseRenderer) -> None:
         """Initialize the object.
 
@@ -314,6 +327,7 @@ class Handlers:
         """
         self._config = config
         self._handlers: Dict[str, BaseHandler] = {}
+        self.inventory: Inventory = Inventory(project=self._config["site_name"])
 
     def get_anchor(self, identifier: str) -> Optional[str]:
         """Return the canonical HTML anchor for the identifier, if any of the seen handlers can collect it.
@@ -329,9 +343,8 @@ class Handlers:
                 anchor = handler.renderer.get_anchor(handler.collector.collect(identifier, {}))
             except CollectionError:
                 continue
-            else:
-                if anchor is not None:
-                    return anchor
+            if anchor is not None:
+                return anchor
         return None
 
     def get_handler_name(self, config: dict) -> str:
@@ -343,10 +356,10 @@ class Handlers:
         Returns:
             The name of the handler to use.
         """
-        config = self._config["mkdocstrings"]
+        global_config = self._config["mkdocstrings"]
         if "handler" in config:
             return config["handler"]
-        return config["default_handler"]
+        return global_config["default_handler"]
 
     def get_handler_config(self, name: str) -> dict:
         """Return the global configuration of the given handler.
@@ -382,7 +395,7 @@ class Handlers:
             if handler_config is None:
                 handler_config = self.get_handler_config(name)
             module = importlib.import_module(f"mkdocstrings.handlers.{name}")
-            self._handlers[name] = module.get_handler(
+            self._handlers[name] = module.get_handler(  # type: ignore
                 self._config["theme_name"],
                 self._config["mkdocstrings"]["custom_templates"],
                 **handler_config,
